@@ -448,15 +448,19 @@ public class DocumentStore {
     SortedSet<String> relayFlags = new TreeSet<>();
     SortedSet<String> family = null;
     String version = null;
+    String operatingSystem = null;
     long lastSeenMillis = -1L;
     long consensusWeight = -1L;
     long firstSeenMillis = -1L;
     String hostName = null;
+    List<String> verifiedHostNames = null;
+    List<String> unverifiedHostNames = null;
     Boolean recommendedVersion = null;
     SummaryDocument summaryDocument = new SummaryDocument(isRelay,
         nickname, fingerprint, addresses, lastSeenMillis, running,
         relayFlags, consensusWeight, countryCode, firstSeenMillis,
-        asNumber, contact, family, family, version, hostName,
+        asNumber, contact, family, family, version, operatingSystem,
+        hostName, verifiedHostNames, unverifiedHostNames,
         recommendedVersion);
     return summaryDocument;
   }
