@@ -1,8 +1,11 @@
-/* Copyright 2016--2017 The Tor Project
+/* Copyright 2016--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.onionoo.server;
 
+import static org.torproject.onionoo.docs.DateTimeHelper.ONE_DAY;
+import static org.torproject.onionoo.docs.DateTimeHelper.ONE_MINUTE;
+
 import org.torproject.onionoo.docs.DocumentStore;
 import org.torproject.onionoo.docs.DocumentStoreFactory;
 import org.torproject.onionoo.docs.SummaryDocument;
@@ -12,8 +15,10 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import java.io.File;
+import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.SortedMap;
@@ -97,10 +102,6 @@ public class NodeIndexer implements ServletContextListener, Runnable {
     }
   }
 
-  private static final long ONE_MINUTE = 60L * 1000L;
-
-  private static final long ONE_DAY = 24L * 60L * ONE_MINUTE;
-
   @Override
   public void run() {
     try {
@@ -126,6 +127,7 @@ public class NodeIndexer implements ServletContextListener, Runnable {
     indexerThread.interrupt();
   }
 
+  /* specialTime is only used for testing, see ResourceServletTest */
   private long specialTime = -1L;
 
   private void indexNodeStatuses() {
@@ -155,6 +157,8 @@ public class NodeIndexer implements ServletContextListener, Runnable {
     Map<String, Set<String>> newRelaysByFamily = new HashMap<>();
     Map<String, Set<String>> newRelaysByVersion = new HashMap<>();
     Map<String, Set<String>> newBridgesByVersion = new HashMap<>();
+    Map<String, Set<String>> newRelaysByOperatingSystem = new HashMap<>();
+    Map<String, Set<String>> newBridgesByOperatingSystem = new HashMap<>();
     Map<String, Set<String>> newRelaysByHostName = new HashMap<>();
     Map<Boolean, Set<String>> newRelaysByRecommendedVersion = new HashMap<>();
     newRelaysByRecommendedVersion.put(true, new HashSet<>());
@@ -196,23 +200,36 @@ public class NodeIndexer implements ServletContextListener, Runnable {
           .toUpperCase();
       newRelayFingerprintSummaryLines.put(fingerprint, entry);
       newRelayFingerprintSummaryLines.put(hashedFingerprint, entry);
-      if (entry.getCountryCode() != null) {
-        String countryCode = entry.getCountryCode();
-        if (!newRelaysByCountryCode.containsKey(countryCode)) {
-          newRelaysByCountryCode.put(countryCode,
-              new HashSet<String>());
-        }
-        newRelaysByCountryCode.get(countryCode).add(fingerprint);
-        newRelaysByCountryCode.get(countryCode).add(hashedFingerprint);
+      String countryCode;
+      if (null != entry.getCountryCode()) {
+        countryCode = entry.getCountryCode();
+      } else {
+        /* The country code xz will never be assigned for use with ISO 3166-1
+         * and is "user-assigned". Fun fact: UN/LOCODE assigns XZ to represent
+         * installations in international waters. */
+        countryCode = "xz";
       }
-      if (entry.getAsNumber() != null) {
-        String asNumber = entry.getAsNumber();
-        if (!newRelaysByAsNumber.containsKey(asNumber)) {
-          newRelaysByAsNumber.put(asNumber, new HashSet<String>());
-        }
-        newRelaysByAsNumber.get(asNumber).add(fingerprint);
-        newRelaysByAsNumber.get(asNumber).add(hashedFingerprint);
+      if (!newRelaysByCountryCode.containsKey(countryCode)) {
+        newRelaysByCountryCode.put(countryCode,
+            new HashSet<String>());
       }
+      newRelaysByCountryCode.get(countryCode).add(fingerprint);
+      newRelaysByCountryCode.get(countryCode).add(hashedFingerprint);
+      String asNumber;
+      if (null != entry.getAsNumber()) {
+        asNumber = entry.getAsNumber();
+      } else {
+        /* Autonomous system number 0 is reserved by RFC6707, to be used for
+         * networks that are not routed. The use of this number should be,
+         * and in the majority of cases probably is, filtered and so it
+         * shouldn't appear in any lookup databases. */
+        asNumber = "AS0";
+      }
+      if (!newRelaysByAsNumber.containsKey(asNumber)) {
+        newRelaysByAsNumber.put(asNumber, new HashSet<String>());
+      }
+      newRelaysByAsNumber.get(asNumber).add(fingerprint);
+      newRelaysByAsNumber.get(asNumber).add(hashedFingerprint);
       for (String flag : entry.getRelayFlags()) {
         String flagLowerCase = flag.toLowerCase();
         if (!newRelaysByFlag.containsKey(flagLowerCase)) {
@@ -266,8 +283,24 @@ public class NodeIndexer implements ServletContextListener, Runnable {
         newRelaysByVersion.get(version).add(fingerprint);
         newRelaysByVersion.get(version).add(hashedFingerprint);
       }
-      String hostName = entry.getHostName();
-      if (null != hostName) {
+      String operatingSystem = entry.getOperatingSystem();
+      if (null != operatingSystem) {
+        if (!newRelaysByOperatingSystem.containsKey(operatingSystem)) {
+          newRelaysByOperatingSystem.put(operatingSystem, new HashSet<>());
+        }
+        newRelaysByOperatingSystem.get(operatingSystem).add(fingerprint);
+        newRelaysByOperatingSystem.get(operatingSystem).add(hashedFingerprint);
+      }
+      List<String> allHostNames = new ArrayList<>();
+      List<String> verifiedHostNames = entry.getVerifiedHostNames();
+      if (null != verifiedHostNames) {
+        allHostNames.addAll(verifiedHostNames);
+      }
+      List<String> unverifiedHostNames = entry.getUnverifiedHostNames();
+      if (null != unverifiedHostNames) {
+        allHostNames.addAll(unverifiedHostNames);
+      }
+      for (String hostName : allHostNames) {
         String hostNameLowerCase = hostName.toLowerCase();
         if (!newRelaysByHostName.containsKey(hostNameLowerCase)) {
           newRelaysByHostName.put(hostNameLowerCase, new HashSet<>());
@@ -344,6 +377,16 @@ public class NodeIndexer implements ServletContextListener, Runnable {
         newBridgesByVersion.get(version).add(hashedFingerprint);
         newBridgesByVersion.get(version).add(hashedHashedFingerprint);
       }
+      String operatingSystem = entry.getOperatingSystem();
+      if (null != operatingSystem) {
+        if (!newBridgesByOperatingSystem.containsKey(operatingSystem)) {
+          newBridgesByOperatingSystem.put(operatingSystem, new HashSet<>());
+        }
+        newBridgesByOperatingSystem.get(operatingSystem)
+            .add(hashedFingerprint);
+        newBridgesByOperatingSystem.get(operatingSystem)
+            .add(hashedHashedFingerprint);
+      }
       Boolean recommendedVersion = entry.getRecommendedVersion();
       if (null != recommendedVersion) {
         newBridgesByRecommendedVersion.get(recommendedVersion).add(
@@ -371,6 +414,8 @@ public class NodeIndexer implements ServletContextListener, Runnable {
     newNodeIndex.setBridgesPublishedMillis(bridgesLastPublishedMillis);
     newNodeIndex.setRelaysByVersion(newRelaysByVersion);
     newNodeIndex.setBridgesByVersion(newBridgesByVersion);
+    newNodeIndex.setRelaysByOperatingSystem(newRelaysByOperatingSystem);
+    newNodeIndex.setBridgesByOperatingSystem(newBridgesByOperatingSystem);
     newNodeIndex.setRelaysByHostName(newRelaysByHostName);
     newNodeIndex.setRelaysByRecommendedVersion(newRelaysByRecommendedVersion);
     newNodeIndex.setBridgesByRecommendedVersion(newBridgesByRecommendedVersion);
