@@ -1,8 +1,9 @@
-/* Copyright 2013--2017 The Tor Project
+/* Copyright 2013--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.onionoo.updater;
 
+import org.torproject.onionoo.util.DomainNameSystem;
 import org.torproject.onionoo.util.FormattingUtils;
 
 import java.util.ArrayList;
@@ -24,12 +25,18 @@ public class ReverseDomainNameResolver {
 
   private static final int RDNS_LOOKUP_WORKERS_NUM = 5;
 
+  private DomainNameSystem domainNameSystem;
+
   private Map<String, Long> addressLastLookupTimes;
 
   Set<String> rdnsLookupJobs;
 
   Map<String, String> rdnsLookupResults;
 
+  Map<String, List<String>> rdnsVerifiedLookupResults;
+
+  Map<String, List<String>> rdnsUnverifiedLookupResults;
+
   List<Long> rdnsLookupMillis;
 
   long startedRdnsLookups;
@@ -43,6 +50,7 @@ public class ReverseDomainNameResolver {
   /** Starts reverse domain name lookups in one or more background
    * threads and returns immediately. */
   public void startReverseDomainNameLookups() {
+    this.domainNameSystem = new DomainNameSystem();
     this.startedRdnsLookups = System.currentTimeMillis();
     this.rdnsLookupJobs = new HashSet<>();
     for (Map.Entry<String, Long> e :
@@ -53,6 +61,8 @@ public class ReverseDomainNameResolver {
       }
     }
     this.rdnsLookupResults = new HashMap<>();
+    this.rdnsVerifiedLookupResults = new HashMap<>();
+    this.rdnsUnverifiedLookupResults = new HashMap<>();
     this.rdnsLookupMillis = new ArrayList<>();
     this.rdnsLookupWorkers = new ArrayList<>();
     for (int i = 0; i < RDNS_LOOKUP_WORKERS_NUM; i++) {
@@ -83,19 +93,42 @@ public class ReverseDomainNameResolver {
     }
   }
 
+  /** Returns reverse domain name verified lookup results. */
+  public Map<String, List<String>> getVerifiedLookupResults() {
+    synchronized (this.rdnsVerifiedLookupResults) {
+      return new HashMap<>(this.rdnsVerifiedLookupResults);
+    }
+  }
+
+  /** Returns reverse domain name unverified lookup results. */
+  public Map<String, List<String>> getUnverifiedLookupResults() {
+    synchronized (this.rdnsUnverifiedLookupResults) {
+      return new HashMap<>(this.rdnsUnverifiedLookupResults);
+    }
+  }
+
   /** Returns the time in milliseconds since the epoch when reverse domain
    * lookups have been started. */
   public long getLookupStartMillis() {
     return this.startedRdnsLookups;
   }
 
+  public DomainNameSystem getDomainNameSystemInstance() {
+    return this.domainNameSystem;
+  }
+
   /** Returns a string with the number of performed reverse domain name
    * lookups and some simple statistics on lookup time. */
   public String getStatsString() {
     StringBuilder sb = new StringBuilder();
     sb.append("    " + FormattingUtils.formatDecimalNumber(
         rdnsLookupMillis.size()) + " lookups performed\n");
-    if (rdnsLookupMillis.size() > 0) {
+    sb.append("    " + FormattingUtils.formatDecimalNumber(
+        rdnsVerifiedLookupResults.size()) + " verified results found\n");
+    sb.append("    " + FormattingUtils.formatDecimalNumber(
+        rdnsUnverifiedLookupResults.size())
+        + " unverified results found\n");
+    if (!rdnsLookupMillis.isEmpty()) {
       Collections.sort(rdnsLookupMillis);
       sb.append("    " + FormattingUtils.formatMillis(
           rdnsLookupMillis.get(0)) + " minimum lookup time\n");
