@@ -76,6 +76,10 @@ public class DetailsDocumentWriter implements DocumentWriter {
     detailsDocument.setConsensusWeight(
         detailsStatus.getConsensusWeight());
     detailsDocument.setHostName(detailsStatus.getHostName());
+    detailsDocument.setVerifiedHostNames(
+        detailsStatus.getVerifiedHostNames());
+    detailsDocument.setUnverifiedHostNames(
+        detailsStatus.getUnverifiedHostNames());
     String defaultPolicy = detailsStatus.getDefaultPolicy();
     String portList = detailsStatus.getPortList();
     if (defaultPolicy != null && (defaultPolicy.equals("accept")
@@ -143,12 +147,9 @@ public class DetailsDocumentWriter implements DocumentWriter {
         detailsStatus.getExitPolicyV6Summary());
     detailsDocument.setHibernating(detailsStatus.getHibernating());
     if (detailsStatus.getExitAddresses() != null) {
-      SortedSet<String> exitAddressesWithoutOrAddresses =
-          new TreeSet<>(detailsStatus.getExitAddresses().keySet());
-      exitAddressesWithoutOrAddresses.removeAll(
-          detailsStatus.getOrAddresses());
-      detailsDocument.setExitAddresses(new ArrayList<>(
-          exitAddressesWithoutOrAddresses));
+      List<String> exitAddresses = new ArrayList<>(new TreeSet<>(
+          detailsStatus.getExitAddresses().keySet()));
+      detailsDocument.setExitAddresses(exitAddresses);
     }
     detailsDocument.setMeasured(detailsStatus.getMeasured());
     List<String> unreachableOrAddresses = new ArrayList<>();
