@@ -1,4 +1,4 @@
-/* Copyright 2014--2017 The Tor Project
+/* Copyright 2014--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.onionoo.writer;
@@ -33,7 +33,7 @@ public class SummaryDocumentWriter implements DocumentWriter {
   private int deletedDocuments = 0;
 
   @Override
-  public void writeDocuments() {
+  public void writeDocuments(long mostRecentStatusMillis) {
     long relaysLastValidAfterMillis = -1L;
     long bridgesLastPublishedMillis = -1L;
     for (String fingerprint : this.documentStore.list(NodeStatus.class)) {
@@ -92,13 +92,17 @@ public class SummaryDocumentWriter implements DocumentWriter {
       SortedSet<String> effectiveFamily = nodeStatus.getEffectiveFamily();
       String nickname = nodeStatus.getNickname();
       String version = nodeStatus.getVersion();
+      String operatingSystem = nodeStatus.getOperatingSystem();
       String hostName = nodeStatus.getHostName();
+      List<String> verifiedHostNames = nodeStatus.getVerifiedHostNames();
+      List<String> unverifiedHostNames = nodeStatus.getUnverifiedHostNames();
       Boolean recommendedVersion = nodeStatus.getRecommendedVersion();
       SummaryDocument summaryDocument = new SummaryDocument(isRelay,
           nickname, fingerprint, addresses, lastSeenMillis, running,
           relayFlags, consensusWeight, countryCode, firstSeenMillis,
           asNumber, contact, declaredFamily, effectiveFamily, version,
-          hostName, recommendedVersion);
+          operatingSystem, hostName, verifiedHostNames,
+          unverifiedHostNames, recommendedVersion);
       if (this.documentStore.store(summaryDocument, fingerprint)) {
         this.writtenDocuments++;
       }
